@@ -1,4 +1,5 @@
 from should_dsl import matcher
+import re
 
 @matcher
 def equal_to():
@@ -52,3 +53,27 @@ def in_any_order():
         return True
     return (contains_in_any_order, "%s does %shave in any order %s")
 
+@matcher
+def all_of():
+    return (in_any_order()[0], "%s does %shave all of %s")
+
+@matcher
+def any_of():
+    def have_any_of(container, elements):
+        for element in elements:
+            if element in container:
+                return True
+        return False
+    return (have_any_of, "%s does %shave any of %s")
+
+@matcher
+def kind_of():
+    return (lambda obj, kind: isinstance(obj, kind), "%s is %s a kind of %s")
+
+@matcher
+def ended_with():
+    return (lambda x, y: x.endswith(y), "%s is %sended with %s")
+
+@matcher
+def like():
+    return (lambda string, regex: re.match(regex, string) is not None, '"%s" is %slike "%s"')
