@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 import doctest
 import os
+from tests import unittest_example
+
+flags = doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS
 
 if __name__ == '__main__':
     doctests_path = os.path.join(os.path.dirname(__file__), 'doctests')
@@ -8,4 +11,8 @@ if __name__ == '__main__':
         if not doctest_file.endswith('.txt'):
             continue
         doctest.testfile(os.path.join(doctests_path, doctest_file),
-                         optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS)
+                         optionflags=flags)
+
+#    for module in [unittest_example,]:
+#        doctest.testmod(module, optionflags=flags)
+
